<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Program_Name</source>
        <translation>Nome_do_Programa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="46"/>
        <source>Quit application</source>
        <translation>Sair da aplicação</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="49"/>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="56"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="88"/>
        <source>Display help </source>
        <translation>Exibir a ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="91"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="98"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="114"/>
        <source>Back</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="172"/>
        <source>Next</source>
        <translation>Próximo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="198"/>
        <source>About this application</source>
        <translation>Sobre esta aplicação</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="201"/>
        <source>About...</source>
        <translation>Sobre...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="208"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="239"/>
        <location filename="../mainwindow.cpp" line="512"/>
        <location filename="../mainwindow.cpp" line="533"/>
        <source>Select ISO</source>
        <translation>Seleccionar ficheiro ISO</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="250"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select Target USB Device&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Selecionar Dispositivo USB a usar&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="260"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select ISO file&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Seleccionar ficheiro ISO&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="289"/>
        <source>Advanced Options</source>
        <translation>Opções Avançadas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="307"/>
        <source>Make the ext4 filesystem even if one exists</source>
        <translation>Formatar em ext4 mesmo que já esteja formatado nesse sistema</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="314"/>
        <source>Save the original boot directory when updating a live-usb</source>
        <translation>Guardar o directório original boot ao actualizar uma penUSB-executável</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="321"/>
        <source>Use gpt partitioning instead of msdos</source>
        <translation>Usar particionamento gpt em vez de msdos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="324"/>
        <source>GPT partitioning</source>
        <translation>Particionamento GPT</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="331"/>
        <source>Update (only update an existing live-usb)</source>
        <translation>Actualizar (actualizar apenas uma USB-executável existente)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="338"/>
        <source>Don&apos;t replace syslinux files</source>
        <translation>Não substituir os ficheiros syslinux</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="341"/>
        <source>Keep syslinux files</source>
        <translation>Manter os ficheiros syslinux</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="348"/>
        <source>Ignore USB/removable check</source>
        <translation>Ignorar a verificação USB/removível</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="355"/>
        <source>Temporarily disable automounting</source>
        <translation>Desactivar temporariamente a montagem automática</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="365"/>
        <source>Set pmbr_boot disk flag (won&apos;t boot via UEFI)</source>
        <translation>Atribuir o marcador de disco &apos;pmbr_boot&apos; (não iniciará via UEFI)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="372"/>
        <source>Don&apos;t use fuseiso to mount iso files</source>
        <translation>Não usar fuseiso para montar ficheiros iso</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="398"/>
        <source>Size of ESP (uefi) partition:</source>
        <translation>Tamanho da partição ESP (uefi):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="418"/>
        <source>Verbosity (less to more):</source>
        <translation>Nível de detalhe (de menos para mais):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="457"/>
        <source>vfat</source>
        <translation>vfat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="462"/>
        <source>exfat</source>
        <translation>exfat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="467"/>
        <source>ext4</source>
        <translation>ext4</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="472"/>
        <source>ntfs</source>
        <translation>ntfs</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="493"/>
        <source>Make separate data partition (percent)</source>
        <translation>Criar partição de dados separada (percentagem)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="500"/>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="510"/>
        <source>Refresh drive list</source>
        <translation>Actualizar a lista de dispositivos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="524"/>
        <location filename="../mainwindow.cpp" line="457"/>
        <source>Show advanced options</source>
        <translation>Mostrar opções avançadas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="544"/>
        <source>Mode</source>
        <translation>Modo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="559"/>
        <source>Full-featured mode - writable LiveUSB</source>
        <translation>Modo completo - USB-executável alterável</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="569"/>
        <source>Read-only, cannot be used with persistency</source>
        <translation>Só de leitura; não pode ser usado com &apos;persistência&apos;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="572"/>
        <source>Image mode - read-only LiveUSB (dd)</source>
        <translation>Modo de Imagem - USB-executável apenas de leitura (dd)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="586"/>
        <source>For distros other than antiX/MX use image mode (dd).</source>
        <translation>Para distribuições não antiX/MX usar o modo de imagem (dd).</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="634"/>
        <source>Options</source>
        <translation>Opções</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="669"/>
        <source>Percent of USB-device to use:</source>
        <translation>Parte do dispositivo USB a usar (%):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="676"/>
        <source>Label ext partition:</source>
        <translation>Rotular a partição ext:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="724"/>
        <source>Don&apos;t run commands that affect the usb device</source>
        <translation>Não executar commandos que afectem o dispositivo USB</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="727"/>
        <source>Dry run (no change to system)</source>
        <translation>Execução a seco (não altera o sistema)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="734"/>
        <source>clone from a mounted live-usb or iso-file.</source>
        <translation>Clonar a partir de USB-executável ou ficheiro ISO montado.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="737"/>
        <source>Clone an existing live system</source>
        <translation>Clonar um sistema externo existente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="744"/>
        <source>Set up to boot from an encrypted partition, will prompt for pass phrase on first boot</source>
        <translation>Definir para arrancar de partição encriptada; pedirá uma frase-senha no primeiro arranque</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="747"/>
        <source>Encrypt</source>
        <translation>Encriptar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="754"/>
        <source>Clone running live system</source>
        <translation>Clonar o sistema externo em execução</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="72"/>
        <source>Confirmation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="72"/>
        <source>Target device %1 is larger than %2 GB. Do you wish to proceed?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="108"/>
        <location filename="../mainwindow.cpp" line="303"/>
        <location filename="../mainwindow.cpp" line="442"/>
        <source>Failure</source>
        <translation>Falha</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="108"/>
        <source>Source and destination are on the same device, please select again.</source>
        <translation>Origem e destino no mesmo dispositivo; seleccionar de novo.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="140"/>
        <source>Writing %1 using &apos;dd&apos; command to /dev/%2,

Please wait until the the process is completed</source>
        <translation>A gravar %1 em /dev/%2, usando o comando &apos;dd&apos;.

Aguardar até o processo terminar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="301"/>
        <source>Success</source>
        <translation>Êxito</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="301"/>
        <source>LiveUSB creation successful!</source>
        <translation>USB-executável (Instalação externa USB) criada com êxito!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="303"/>
        <source>Error encountered in the LiveUSB creation process</source>
        <translation>Erro no processo de criar a Instalação externa USB-executável</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="363"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="363"/>
        <source>Please select a USB device to write to</source>
        <translation>Seleccionar o dispositivo USB a usar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="366"/>
        <location filename="../mainwindow.cpp" line="526"/>
        <source>clone</source>
        <translation>clonar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="402"/>
        <source>About %1</source>
        <translation>Sobre %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="403"/>
        <source>Version: </source>
        <translation>Versão:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="404"/>
        <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
        <translation>Programa para criar instalações externas USB-executável a partir de ficheiros ISO, de outra instalação externa USB-executável, de CD/DVD-executável ou de um sistema externo em execução.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="406"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Direitos de Autor (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="407"/>
        <source>%1 License</source>
        <translation>%1 Licença</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="415"/>
        <source>%1 Help</source>
        <translation>%1 Ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="426"/>
        <source>Select an ISO file to write to the USB drive</source>
        <translation>Seleccionar um ficheiro ISO a instalar no dispositivo USB</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="426"/>
        <source>ISO Files (*.iso);;All Files (*.*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="436"/>
        <location filename="../mainwindow.cpp" line="508"/>
        <source>Select Source Directory</source>
        <translation>Seleccionar Directório Origem</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="442"/>
        <source>Could not find %1/antiX/linuxfs file</source>
        <translation>Ficheiro %1/antiX/linuxfs não encontrado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="463"/>
        <source>Hide advanced options</source>
        <translation>Ocultar opções avançadas</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="507"/>
        <location filename="../mainwindow.cpp" line="524"/>
        <source>Select Source</source>
        <translation>Seleccionar Origem</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="511"/>
        <location filename="../mainwindow.cpp" line="531"/>
        <source>Select ISO file</source>
        <translation>Seleccionar ficheiro ISO</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../about.cpp" line="32"/>
        <source>License</source>
        <translation>Licença</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="33"/>
        <location filename="../about.cpp" line="43"/>
        <source>Changelog</source>
        <translation>Registo de alterações</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="34"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="51"/>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <source>Error</source>
        <translation type="unfinished">Erro</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <source>You must run this program as root.</source>
        <translation>Este programa tem que ser executado como root (administrador).</translation>
    </message>
</context>
</TS>
